# coding: utf-8

"""
    Lookup/Ibis web service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from identitylib.lookup_client.models.group_all_groups200_response_result import GroupAllGroups200ResponseResult

class GroupAllGroups200Response(BaseModel):
    """
    GroupAllGroups200Response
    """
    result: Optional[GroupAllGroups200ResponseResult] = None
    __properties = ["result"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GroupAllGroups200Response:
        """Create an instance of GroupAllGroups200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GroupAllGroups200Response:
        """Create an instance of GroupAllGroups200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GroupAllGroups200Response.parse_obj(obj)

        _obj = GroupAllGroups200Response.parse_obj({
            "result": GroupAllGroups200ResponseResult.from_dict(obj.get("result")) if obj.get("result") is not None else None
        })
        return _obj


